@@ -26,6 +26,7 @@ __all__ = (
     "EnvironmentStatusType",
     "EnvironmentTypeType",
     "ListEnvironmentsPaginatorName",
+    "ManagedCredentialsActionType",
     "ManagedCredentialsStatusType",
     "MemberPermissionsType",
     "PermissionsType",
@@ -42,6 +43,7 @@ EnvironmentStatusType = Literal[
 ]
 EnvironmentTypeType = Literal["ec2", "ssh"]
 ListEnvironmentsPaginatorName = Literal["list_environments"]
+ManagedCredentialsActionType = Literal["DISABLE", "ENABLE"]
 ManagedCredentialsStatusType = Literal[
     "DISABLED_BY_COLLABORATOR",
     "DISABLED_BY_DEFAULT",
