@@ -20,6 +20,7 @@ from .literals import (
     EnvironmentLifecycleStatusType,
     EnvironmentStatusType,
     EnvironmentTypeType,
+    ManagedCredentialsActionType,
     ManagedCredentialsStatusType,
     MemberPermissionsType,
     PermissionsType,
@@ -79,6 +80,7 @@ _OptionalCreateEnvironmentEC2RequestRequestTypeDef = TypedDict(
         "ownerArn": str,
         "tags": List["TagTypeDef"],
         "connectionType": ConnectionTypeType,
+        "dryRun": bool,
     },
     total=False,
 )
@@ -349,6 +351,7 @@ _OptionalUpdateEnvironmentRequestRequestTypeDef = TypedDict(
     {
         "name": str,
         "description": str,
+        "managedCredentialsAction": ManagedCredentialsActionType,
     },
     total=False,
 )
